---------------------
Coordinate Transforms
---------------------

Numpy
~~~~~

.. currentmodule:: africanus.coordinates

.. autosummary::
    radec_to_lm
    radec_to_lmn
    lm_to_radec
    lmn_to_radec

.. autofunction:: radec_to_lm
.. autofunction:: radec_to_lmn
.. autofunction:: lm_to_radec
.. autofunction:: lmn_to_radec

Dask
~~~~

.. currentmodule:: africanus.coordinates.dask

.. autosummary::
    radec_to_lm
    radec_to_lmn
    lm_to_radec
    lmn_to_radec

.. autofunction:: radec_to_lm
.. autofunction:: radec_to_lmn
.. autofunction:: lm_to_radec
.. autofunction:: lmn_to_radec
